## Structure

```
claude_speak/
├── src/claude_speak/*           # code
├── main.py                      # Basic entry point
├── pyproject.toml               # Project configuration
├── CLAUDE.md                    # Development guidelines
├── RealtimeSTT.md               # RealtimeSTT option details & defaults
└── README.md                    # Project documentation
```

## Rules

1. Code Quality
   - Type hints required for all code
   - Follow existing patterns exactly
   - Use Google style for docstring

